Pytest plugin
=============

.. _aiomisc-pytest: https://pypi.org/project/aiomisc-pytest

Starting with version 17, pytest integration is distributed as a
separate package aiomisc-pytest_. See the documentation for the
aiomisc-pytest_ module for further instructions.
